@@ -7,8 +7,9 @@ import plotly.graph_objects as go
 from trdb2py.statistics import buildPNLWinRateInYears, buildPNLListWinRateInYears2, buildPNLWinRateInMonths, buildPNLListWinRateInMonths2
 
 
-def showAssetCandles(title: str, dfCandles: pd.DataFrame, columm: str = 'close', toImg: bool = False):
-    fig = px.line(dfCandles, x='date', y=columm, title=title)
+def showAssetCandles(title: str, dfCandles: pd.DataFrame, columm: str = 'close', toImg: bool = False, width=1024, height=768):
+    fig = px.line(dfCandles, x='date', y=columm,
+                  title=title, width=width, height=height)
 
     if toImg:
         fig.show(renderer="png")
@@ -16,7 +17,7 @@ def showAssetCandles(title: str, dfCandles: pd.DataFrame, columm: str = 'close',
         fig.show()
 
 
-def showPNL(pnl: dict, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d', toImg: bool = False):
+def showPNL(pnl: dict, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d', toImg: bool = False, width=1024, height=768):
     fv0 = {'date': [], 'value': []}
     for v in pnl['pnl'].values:
         fv0['date'].append(datetime.fromtimestamp(
@@ -27,7 +28,8 @@ def showPNL(pnl: dict, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d', toIm
         else:
             fv0['value'].append(v.value - v.cost)
 
-    fig = px.line(pd.DataFrame(fv0), x='date', y='value', title=pnl['title'])
+    fig = px.line(pd.DataFrame(fv0), x='date', y='value',
+                  title=pnl['title'], width=width, height=height)
 
     if toImg:
         fig.show(renderer="png")
@@ -35,7 +37,7 @@ def showPNL(pnl: dict, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d', toIm
         fig.show()
 
 
-def showPNLs(lstpnl: list, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d', toImg: bool = False):
+def showPNLs(lstpnl: list, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d', toImg: bool = False, width=1024, height=768):
     fig = go.Figure()
 
     for pnl in lstpnl:
@@ -55,13 +57,19 @@ def showPNLs(lstpnl: list, isPerValue: bool = True, dtFormat: str = '%Y-%m-%d',
                                  mode='lines',
                                  name=pnl['title']))
 
+    fig.update_layout(
+        autosize=False,
+        width=width,
+        height=height,
+    )
+
     if toImg:
         fig.show(renderer="png")
     else:
         fig.show()
 
 
-def showHeatmap(df: pd.DataFrame, columns: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False):
+def showHeatmap(df: pd.DataFrame, columns: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False, width=1024, height=768):
     data = []
 
     for index, row in df.iterrows():
@@ -79,13 +87,19 @@ def showHeatmap(df: pd.DataFrame, columns: list, valtype: str = '', valoff: floa
         x=columns,
         y=df['title']))
 
+    fig.update_layout(
+        autosize=False,
+        width=width,
+        height=height,
+    )
+
     if toImg:
         fig.show(renderer="png")
     else:
         fig.show()
 
 
-def showHeatmapWinRateInYears(lstpnl: list, sortby: str = '', valtype: str = '', valoff: float = 0.0, toImg: bool = False):
+def showHeatmapWinRateInYears(lstpnl: list, sortby: str = '', valtype: str = '', valoff: float = 0.0, toImg: bool = False, width=1024, height=768):
     ret = buildPNLWinRateInYears(lstpnl)
     columns = []
 
@@ -101,10 +115,10 @@ def showHeatmapWinRateInYears(lstpnl: list, sortby: str = '', valtype: str = '',
 
     # print(columns)
 
-    showHeatmap(df, columns, valtype, valoff, toImg)
+    showHeatmap(df, columns, valtype, valoff, toImg, width, height)
 
 
-def showWinRateInYears(lstpnl: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False):
+def showWinRateInYears(lstpnl: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False, width=1024, height=768):
     arr = buildPNLListWinRateInYears2(lstpnl)
 
     fig = go.Figure()
@@ -125,13 +139,19 @@ def showWinRateInYears(lstpnl: list, valtype: str = '', valoff: float = 0.0, toI
                                      mode='lines',
                                      name=v['title']))
 
+    fig.update_layout(
+        autosize=False,
+        width=width,
+        height=height,
+    )
+
     if toImg:
         fig.show(renderer="png")
     else:
         fig.show()
 
 
-def showHeatmapWinRateInMonths(lstpnl: list, sortby: str = '', valtype: str = '', valoff: float = 0.0, toImg: bool = False):
+def showHeatmapWinRateInMonths(lstpnl: list, sortby: str = '', valtype: str = '', valoff: float = 0.0, toImg: bool = False, width=1024, height=768):
     ret = buildPNLWinRateInMonths(lstpnl)
     columns = []
 
@@ -155,10 +175,10 @@ def showHeatmapWinRateInMonths(lstpnl: list, sortby: str = '', valtype: str = ''
 
     # print(columns)
 
-    showHeatmap(df, columns, valtype, valoff, toImg)
+    showHeatmap(df, columns, valtype, valoff, toImg, width, height)
 
 
-def showWinRateInMonths(lstpnl: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False):
+def showWinRateInMonths(lstpnl: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False, width=1024, height=768):
     arr = buildPNLListWinRateInMonths2(lstpnl)
 
     fig = go.Figure()
@@ -179,6 +199,12 @@ def showWinRateInMonths(lstpnl: list, valtype: str = '', valoff: float = 0.0, to
                                      mode='lines',
                                      name=v['title']))
 
+    fig.update_layout(
+        autosize=False,
+        width=width,
+        height=height,
+    )
+
     if toImg:
         fig.show(renderer="png")
     else:
